ApiCallType class

Class For two types of API Calls required for Flutter Instamojo

Constructors

ApiCallType.createOrder({required CreateOrderBody? createOrderBody, String? orderCreationUrl})
Class For Creating Order ID --- Flutter Instamojo
ApiCallType.startPayment({String? orderId})
Class For Invoking Payment Directly --- Flutter Instamojo

Properties

callType ↔ Type
getter/setter pair
createOrderBody → CreateOrderBody?
final
hashCode → int
The hash code for this object.
no setterinherited
orderCreationUrl → String?
final
orderId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited