CreateOrderBody class

Constructors

CreateOrderBody({@required String? amount, @required String? buyerEmail, @required String? buyerName, @required String? buyerPhone, @required String? description})
const
CreateOrderBody.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
buyerEmail → String?
final
buyerName → String?
final
buyerPhone → String?
final
description → String?
final
env → String?
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(String env) → Map<String, String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited