EmiList class

Constructors

EmiList({String? bankName, String? bankCode, List<Rate>? rates})
EmiList.fromJson(Map<String, dynamic> json)
factory

Properties

bankCode → String?
final
bankName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
rates → List<Rate>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited