Order class

Constructors

Order({String? amount})
Order.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAmountDetails ↔ OrderWithFees?
getter/setter pair
totalOrderAmountDetails → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited