OrderWithFees class

Constructors

OrderWithFees({String? orderWithConvinenceFees, String? totalConvinenceFees, String? convinenceFees, String? gstPercent = "18.0", ConvinenceFeesValues? convinenceFeesValue, String? gstFees})

Properties

convinenceFees ↔ String?
getter/setter pair
convinenceFeesValue ↔ ConvinenceFeesValues?
getter/setter pair
convinenceFeesValueDetails → dynamic
no setter
getGSTPercent → dynamic
no setter
gstFees ↔ String?
getter/setter pair
gstPercent ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orderWithConvinenceFees ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalConvinenceFees ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited