PaymentOptions class

Constructors

PaymentOptions({String? paymentUrl, Options? cardOptions, Options? emiOptions, NetbankingOptions? netbankingOptions, WalletOptions? walletOptions, UpiOptions? upiOptions})
PaymentOptions.fromJson(Map<String, dynamic> json)
factory

Properties

cardOptions → Options?
final
emiOptions → Options?
final
hashCode → int
The hash code for this object.
no setterinherited
netbankingOptions → NetbankingOptions?
final
paymentUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upiOptions → UpiOptions?
final
walletOptions → WalletOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited