CardUtils class

Constructors

CardUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

convertYearTo4Digits(int year) → int
Convert the two-digit year to four-digit year if necessary
getCardIcon(CardType? cardType) → Widget
getCardTypeFrmNumber(String input) → CardType
getCleanedNumber(String text) → String
getExpiryDate(String value) → List<int>
hasDateExpired(int month, int year) → bool
hasMonthPassed(int year, int month) → bool
hasYearPassed(int year) → bool
isNotExpired(int year, int month) → bool
validateCardNum(String? input) → String?
With the card number with Luhn Algorithm https://en.wikipedia.org/wiki/Luhn_algorithm
validateCVV(String? value) → String?
validateDate(String? value) → String?